@@ -6,7 +6,7 @@
 # David Hunter <dhunter@stat.psu.edu> and Mark S. Handcock
 # <handcock@u.washington.edu>.
 #
-# Last Modified 10/19/06
+# Last Modified 1/31/08
 # Licensed under the GNU General Public License version 2 (June, 1991)
 #
 # Part of the R/network package
@@ -248,6 +248,8 @@ network.initialize<-function(n,directed=TRUE,hyper=FALSE,loops=FALSE,multiple=FA
   class(g)<-"network"
   #Set the required vertex attribute
   g<-set.vertex.attribute(g,"na",rep(FALSE,n),1:n)
+  #Create default vertex names
+  network.vertex.names(g)<-1:n
   #Return
   g
 }
