@@ -4,7 +4,7 @@
 # access.h
 #
 # Written by Carter T. Butts <buttsc@uci.edu>
-# Last Modified 9/16/06
+# Last Modified 1/31/08
 # Licensed under the GNU General Public License version 2 (June, 1991)
 #
 # Part of the R/network package
@@ -31,21 +31,21 @@
 
 /*INTERNAL ROUTINES---------------------------------------------------------*/
 
-SEXP deleteEdgeAttribute(SEXP x, int e, char *attrname);
+SEXP deleteEdgeAttribute(SEXP x, int e, const char *attrname);
 
-SEXP deleteNetworkAttribute(SEXP x, char *attrname);
+SEXP deleteNetworkAttribute(SEXP x, const char *attrname);
 
-SEXP deleteVertexAttribute(SEXP x, int v, char *attrname);
+SEXP deleteVertexAttribute(SEXP x, int v, const char *attrname);
 
-SEXP getEdgeAttribute(SEXP x, int e, char *str);
+SEXP getEdgeAttribute(SEXP x, int e, const char *str);
 
-SEXP getEdgeIDs(SEXP x, int v, int alter, char *neighborhood, int naOmit);
+SEXP getEdgeIDs(SEXP x, int v, int alter, const char *neighborhood, int naOmit);
 
-SEXP getEdges(SEXP x, int v, int alter, char *neighborhood, int naOmit);
+SEXP getEdges(SEXP x, int v, int alter, const char *neighborhood, int naOmit);
 
-SEXP getNeighborhood(SEXP x, int v, char *type, int naOmit);
+SEXP getNeighborhood(SEXP x, int v, const char *type, int naOmit);
 
-SEXP getNetworkAttribute(SEXP x, char *str);
+SEXP getNetworkAttribute(SEXP x, const char *str);
 
 int hasLoops(SEXP x);
 
@@ -63,9 +63,9 @@ int networkEdgecount(SEXP x, int naOmit);
 
 int networkSize(SEXP x);
 
-SEXP setNetworkAttribute(SEXP x, char *attrname, SEXP value);
+SEXP setNetworkAttribute(SEXP x, const char *attrname, SEXP value);
 
-SEXP setVertexAttribute(SEXP x, char *attrname, SEXP value, int v);
+SEXP setVertexAttribute(SEXP x, const char *attrname, SEXP value, int v);
 
 
 /*R-CALLABLE ROUTINES-------------------------------------------------------*/
