@@ -58,7 +58,7 @@ check[20]<-all(temp[,1]==temp[1,])   #Verify edges
 temp<-permute.vertexIDs(temp,5:1)       #Permute 
 check[21]<-all(temp[1,]==c(0,0,0,0,1))  #Verify permutation
 check[22]<-all(temp[,5]==rep(1,5))
-check[23]<-get.neighborhood(temp,1)==5               #Check neighborhoods
+check[23]<-all(get.neighborhood(temp,1)%in%c(5,1)) #Check neighborhoods
 check[24]<-all(sort(get.neighborhood(temp,5))==1:5)
 check[25]<-length(get.edges(temp,5))==5            #Check get.edges
 check[26]<-length(get.edges(temp,5,2))==1
@@ -126,12 +126,11 @@ g<-rgraph(10)
 temp<-network(g,names.eval="value",ignore.eval=FALSE)
 temp2<-network(g*2,names.eval="value",ignore.eval=FALSE)
 check[54]<-all(g==as.sociomatrix(temp+temp2))
-#Note: prior to R 2.4.0, could use "+" instead of "+.network" here...
-check[55]<-all(g*3==as.sociomatrix("+.network"(temp,temp2,"value"),"value"))
+check[55]<-all(g*3==as.sociomatrix(sum(temp,temp2,attrname="value"),"value"))
 check[56]<-all(g==as.sociomatrix(temp*temp2))
-check[57]<-all(g*2==as.sociomatrix("*.network"(temp,temp2,"value"),"value"))
+check[57]<-all(g*2==as.sociomatrix(prod(temp,temp2,attrname="value"),"value"))
 check[58]<-all(0==as.sociomatrix(temp-temp2))
-check[59]<-all(-g==as.sociomatrix("-.network"(temp,temp2,"value"),"value"))
+check[59]<-all(-g==as.sociomatrix(sum(temp,-as.sociomatrix(temp2,"value"),attrname="value"),"value"))
 check[60]<-all(((g%*%g)>0)==as.sociomatrix("%c%.network"(temp,temp2)))
 check[61]<-all(((g%*%g)>0)==as.sociomatrix(temp%c%temp2))
 check[62]<-all(((!temp)[,]==!g)[diag(10)<1])
